@@ -125,7 +125,7 @@ TEST { stream(1, 44, 2)->join("-") }
 '1-44-2';
 
 sub is_pair_purearray {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     [is_pair($v), is_purearray($v)]
 }
