@@ -119,67 +119,67 @@ sub array_equal {
 }
 
 sub array_maybe_first {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     $_[0][0]
 }
 
 sub array_perhaps_first {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     @$a ? $$a[0] : ()
 }
 
 sub array_first {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     @$a or die "can't take the first of an empty array";
     $$a[0]
 }
 
 sub array_maybe_rest {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     @$a ? [@$a[1 .. $#$a]] : undef
 }
 
 sub array_perhaps_rest {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     @$a ? [@$a[1 .. $#$a]] : ()
 }
 
 sub array_rest {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     @$a or die "can't take the rest of an empty array";
     [@$a[1 .. $#$a]]
 }
 
 sub array_maybe_first_and_rest {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     @$a ? (array_first $a, array_rest $a) : undef
 }
 
 sub array_first_and_rest {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     (array_first $a, array_rest $a)
 }
 
 sub array_second {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     $_[0][1]
 }
 
 sub array_maybe_ref {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($a, $i) = @_;
     $$a[$i]
 }
 
 sub array_ref {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($a, $i) = @_;
 
     # XX also check that $i is integer?
@@ -193,19 +193,19 @@ TEST_EXCEPTION { array_ref [5], 1 } "index out of bounds: 1";
 TEST_EXCEPTION { array_ref [5], -1 } "index out of bounds: -1";
 
 sub array_length {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     scalar @{ $_[0] }
 }
 
 sub array_is_null {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     @{ $_[0] } == 0
 }
 
 # functional updates
 
 sub array_set {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($a, $i, $v) = @_;
     my $a2 = [@$a];
     $$a2[$i] = $v;
@@ -213,7 +213,7 @@ sub array_set {
 }
 
 sub array_update {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($a, $i, $fn) = @_;
     my $a2 = [@$a];
     $$a2[$i] = &$fn($$a2[$i]);
@@ -228,7 +228,7 @@ sub array_push {
 }
 
 sub array_pop {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     my $a2  = [@$a];
     my $v   = pop @$a2;
@@ -236,7 +236,7 @@ sub array_pop {
 }
 
 sub array_shift {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     my $a2  = [@$a];
     my $v   = shift @$a2;
@@ -258,19 +258,19 @@ sub array_sub {
 }
 
 sub array_take {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($a, $n) = @_;
     array_sub $a, 0, $n
 }
 
 sub array_drop {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($a, $n) = @_;
     array_sub $a, $n, array_length $a
 }
 
 sub array_take_while {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $s) = @_;
     my $i   = 0;
     my $len = @$s;
@@ -281,7 +281,7 @@ sub array_take_while {
 }
 
 sub array_take_while_and_rest {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $s) = @_;
     my $i   = 0;
     my $len = @$s;
@@ -292,7 +292,7 @@ sub array_take_while_and_rest {
 }
 
 sub array_drop_while {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $s) = @_;
     my $i   = 0;
     my $len = @$s;
@@ -321,20 +321,20 @@ sub array_append {
 }
 
 sub array_reverse {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     [reverse @$v]
 }
 
 sub array_xone {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     @$a == 1 or croak "expecting 1 element, got " . @$a;
     $$a[0]
 }
 
 sub array_perhaps_one {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     if (@$a == 1) {
         $$a[0]
@@ -344,7 +344,7 @@ sub array_perhaps_one {
 }
 
 sub array_hashing_uniq {
-    @_ >= 1 and @_ <= 2 or fp_croak_nargs "1-2";
+    @_ >= 1 and @_ <= 2 or fp_croak_arity "1-2";
     my ($ary, $maybe_warn) = @_;
     my %seen;
     [
@@ -358,7 +358,7 @@ sub array_hashing_uniq {
 }
 
 sub array_zip2 {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($l, $m) = @_;
     my @res;
     my $len = min(scalar @$l, scalar @$m);
@@ -369,13 +369,13 @@ sub array_zip2 {
 }
 
 sub array_for_each {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $v) = @_;
     for my $a (@$v) { &$fn($a) }
 }
 
 sub array_map {
-    @_ > 1 or fp_croak_nargs "> 1";
+    @_ > 1 or fp_croak_arity "> 1";
     my $fn  = shift;
     my $len = min(map { scalar @$_ } @_);
     my @res;
@@ -396,7 +396,7 @@ TEST {
 
 # (should one use multi-arg stream_map with stream_iota instead?..)
 sub array_map_with_index {
-    @_ > 1 or fp_croak_nargs "> 1";
+    @_ > 1 or fp_croak_arity "> 1";
     my $fn  = shift;
     my $len = min(map { scalar @$_ } @_);
     my @res;
@@ -412,7 +412,7 @@ TEST {
 [[0, "a", 20], [1, "b", 21]];
 
 sub array_map_with_islast {
-    @_ > 1 or fp_croak_nargs "> 1";
+    @_ > 1 or fp_croak_arity "> 1";
     my $fn   = shift;
     my $len  = min(map { scalar @$_ } @_);
     my $last = $len - 1;
@@ -433,7 +433,7 @@ TEST {
 [['', 1, "b"], [1, 2, "c"]];
 
 sub array_to_hash_map {
-    @_ > 1 or fp_croak_nargs "> 1";
+    @_ > 1 or fp_croak_arity "> 1";
     my $fn  = shift;
     my $len = min(map { scalar @$_ } @_);
     my %res;
@@ -455,7 +455,7 @@ TEST {
 +{ 'a' => 4, 'b' => 9, 'c' => 16 };
 
 sub array_filter {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $v) = @_;
     [grep { &$fn($_) } @$v]
 }
@@ -477,7 +477,7 @@ TEST { array_zip [3, 4], [qw(a b c)] }
 # see discussion for `stream_fold` in `FP::Stream` for the reasoning
 # behind the argument order of $fn
 sub array_fold {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $start, $ary) = @_;
     for (@$ary) {
         $start = &$fn($_, $start);
@@ -497,7 +497,7 @@ TEST {
 [2, 1];
 
 sub array_fold_right {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $tail, $a) = @_;
     my $i = @$a - 1;
     while ($i >= 0) {
@@ -515,7 +515,7 @@ TEST {
 [1, 2, 3];
 
 sub array_intersperse {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($ary, $val) = @_;
     my @res;
     for (@$ary) {
@@ -530,7 +530,7 @@ TEST { array_intersperse [1, 2, 3], "a" }
 TEST { array_intersperse [], "a" } [];
 
 sub array_strings_join {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($ary, $val) = @_;
     join $val, @$ary
 }
@@ -539,7 +539,7 @@ TEST { array_strings_join [1, 2, 3], "-" }
 "1-2-3";
 
 sub array_to_string {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($ary) = @_;
     join "", @$ary
 }
@@ -548,7 +548,7 @@ TEST { array_to_string [1, 2, 3] }
 "123";
 
 sub array_every {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $ary) = @_;
     for (@$ary) {
         return 0 unless &$fn($_);
@@ -570,7 +570,7 @@ TEST {
 1;
 
 sub array_any {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $ary) = @_;
     for (@$ary) {
         return 1 if &$fn($_);
@@ -596,18 +596,18 @@ TEST {
 1;
 
 sub array_sum {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     array_fold \&add, 0, $_[0]
 }
 
 sub array_last {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($a) = @_;
     $$a[-1]
 }
 
 sub array_to_hash_group_by {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($ary, $on) = @_;
     my %res;
     for (@$ary) {
@@ -618,7 +618,7 @@ sub array_to_hash_group_by {
 
 # adapted from FP::List
 sub array_perhaps_find_tail {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $s,) = @_;
     my $len = @$s;
     my $i   = 0;
@@ -644,7 +644,7 @@ LP: {
 }
 
 sub array_perhaps_find {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $l) = @_;
     if (my ($l) = array_perhaps_find_tail($fn, $l)) {
         $l->first
