@@ -102,7 +102,7 @@ use FP::Carp;
 our $immutable = 1;    # whether new instances are to be immutable
 
 sub is_purearray {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // return;
     $v->isa("FP::_::PureArray")
@@ -113,12 +113,12 @@ sub purearray {
 }
 
 sub array_clone_to_purearray {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     FP::_::PureArray->new_from_array([@{ $_[0] }])
 }
 
 sub array_to_purearray {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     FP::_::PureArray->new_from_array($_[0])
 }
 
@@ -145,7 +145,7 @@ package FP::_::PureArray {
     use Chj::NamespaceCleanAbove;
 
     sub new_from_array {
-        @_ == 2 or fp_croak_nargs 2;
+        @_ == 2 or fp_croak_arity 2;
         my ($class, $a) = @_;
         bless $a, $class;
         if ($FP::PureArray::immutable) {
@@ -156,13 +156,13 @@ package FP::_::PureArray {
     }
 
     sub purearray {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my $s = shift;
         $s
     }
 
     sub mutablearray {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my $s = shift;
         FP::_::MutableArray->new_from_array([@$s])
     }
@@ -184,14 +184,14 @@ package FP::_::PureArray {
     our $pure_warned = 0;
 
     sub pure {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my $a = shift;
         carp "is already pure" unless $pure_warned++;
         $a
     }
 
     sub unsafe_mutable {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my $a = shift;
         Internals::SvREADONLY $_, 0 for @$a;
         Internals::SvREADONLY @$a, 0;
