@@ -183,7 +183,7 @@ use Carp;
 use FP::Carp;
 
 sub stream_iota {
-    @_ <= 2 or fp_croak_nargs 2;
+    @_ <= 2 or fp_croak_arity 2;
     my ($maybe_start, $maybe_n) = @_;
     my $start = $maybe_start // 0;
     if (defined $maybe_n) {
@@ -218,7 +218,7 @@ sub stream_iota {
 
 # Like perl's `..`
 sub stream_range {
-    @_ <= 2 or fp_croak_nargs 2;
+    @_ <= 2 or fp_croak_arity 2;
     my ($maybe_start, $maybe_end) = @_;
     my $start = $maybe_start // 0;
     stream_iota($start, defined $maybe_end ? $maybe_end + 1 - $start : undef);
@@ -232,7 +232,7 @@ TEST { stream_range(2, 1)->array }
 [];
 
 sub stream_step_range {
-    (@_ >= 1 and @_ <= 3) or fp_croak_nargs "1-3";
+    (@_ >= 1 and @_ <= 3) or fp_croak_arity "1-3";
     my ($step, $maybe_start, $maybe_end) = @_;
     my $start   = $maybe_start // 0;
     my $inverse = $step < 0;
@@ -310,7 +310,7 @@ TEST {
 # directly to construct a list.
 
 sub stream_fold {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $start, $l) = @_;
     weaken $_[2];
     my $v;
@@ -343,7 +343,7 @@ TEST { stream_fold(\&cons, null, stream(1, 2))->array }
 [2, 1];
 
 sub stream_sum {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($s) = @_;
     weaken $_[0];
     stream_fold(sub { $_[0] + $_[1] }, 0, $s)
@@ -362,7 +362,7 @@ TEST {
 #  5000050000;
 
 sub stream_append2 {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($l1, $l2) = @_;
     weaken $_[0];
     weaken $_[1];
@@ -447,7 +447,7 @@ TEST {
 ];
 
 sub stream_map {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $l) = @_;
     weaken $_[1];
     lazy {
@@ -459,7 +459,7 @@ sub stream_map {
 *FP::List::List::stream_map = flip \&stream_map;
 
 sub stream_map_with_tail {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $l, $tail) = @_;
     weaken $_[1];
     lazy {
@@ -474,7 +474,7 @@ sub stream_map_with_tail {
 
 # 2-ary (possibly slightly faster) version of stream_zip
 sub stream_zip2 {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($l, $m) = @_;
     do { weaken $_ if is_promise $_ }
         for @_;    #needed?
@@ -536,7 +536,7 @@ sub stream_filter_with_tail;
 # and thus must be applied to non-empty lists.
 
 sub stream_foldr1 {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $l) = @_;
     weaken $_[1];
     lazy {
@@ -554,7 +554,7 @@ sub stream_foldr1 {
 *FP::List::List::stream_foldr1 = flip \&stream_foldr1;
 
 sub stream_fold_right {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $start, $l) = @_;
     weaken $_[2];
     lazy {
@@ -577,7 +577,7 @@ sub make_stream__fold_right {
     my ($length, $ref, $start, $d, $whileP) = @_;
 
     sub {
-        @_ == 3 or fp_croak_nargs 3;
+        @_ == 3 or fp_croak_arity 3;
         my ($fn, $tail, $a) = @_;
         my $len = &$length($a);
         my $rec;
@@ -614,7 +614,7 @@ sub stream__string_fold_right;
     = make_stream__fold_right($string_length, $string_ref, 0, 1, $lt);
 
 sub stream__subarray_fold_right {
-    @_ == 5 or fp_croak_nargs 5;
+    @_ == 5 or fp_croak_arity 5;
     my ($fn, $tail, $a, $start, $maybe_end) = @_;
     make_stream__fold_right($array_length, $array_ref, $start, 1,
         defined $maybe_end ? sub { $_[0] < $_[1] and $_[0] < $maybe_end } : $lt)
@@ -622,7 +622,7 @@ sub stream__subarray_fold_right {
 }
 
 sub stream__subarray_fold_right_reverse {
-    @_ == 5 or fp_croak_nargs 5;
+    @_ == 5 or fp_croak_arity 5;
     my ($fn, $tail, $a, $start, $maybe_end) = @_;
     make_stream__fold_right($array_length, $array_ref, $start, -1,
         defined $maybe_end
@@ -631,7 +631,7 @@ sub stream__subarray_fold_right_reverse {
 }
 
 sub array_to_stream {
-    @_ >= 1 and @_ <= 2 or fp_croak_nargs "1-2";
+    @_ >= 1 and @_ <= 2 or fp_croak_arity "1-2";
     my ($a, $maybe_tail) = @_;
     stream__array_fold_right(*cons, $maybe_tail // null, $a)
 }
@@ -641,27 +641,27 @@ sub stream {
 }
 
 sub subarray_to_stream {
-    @_ >= 2 and @_ <= 4 or fp_croak_nargs "2-4";
+    @_ >= 2 and @_ <= 4 or fp_croak_arity "2-4";
     my ($a, $start, $maybe_end, $maybe_tail) = @_;
     stream__subarray_fold_right(*cons, $maybe_tail // null,
         $a, $start, $maybe_end)
 }
 
 sub subarray_to_stream_reverse {
-    @_ >= 2 and @_ <= 4 or fp_croak_nargs "2-4";
+    @_ >= 2 and @_ <= 4 or fp_croak_arity "2-4";
     my ($a, $start, $maybe_end, $maybe_tail) = @_;
     stream__subarray_fold_right_reverse(*cons, $maybe_tail // null,
         $a, $start, $maybe_end)
 }
 
 sub string_to_stream {
-    @_ >= 1 and @_ <= 2 or fp_croak_nargs "1-2";
+    @_ >= 1 and @_ <= 2 or fp_croak_arity "1-2";
     my ($str, $maybe_tail) = @_;
     stream__string_fold_right(*cons, $maybe_tail // null, $str)
 }
 
 sub stream_to_string {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     weaken $_[0];
     my $str = "";
@@ -677,7 +677,7 @@ sub stream_to_string {
 TEST { stream("Ha", "ll", "o")->string } "Hallo";
 
 sub stream_strings_join {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($l, $val) = @_;
     weaken $_[0];
 
@@ -700,7 +700,7 @@ sub stream_for_each;
 *FP::List::List::stream_for_each = flip \&stream_for_each;
 
 sub stream_drop {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($s, $n) = @_;
     weaken $_[0];
     while ($n > 0) {
@@ -715,7 +715,7 @@ sub stream_drop {
 *FP::List::List::stream_drop = *stream_drop;
 
 sub stream_take {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($s, $n) = @_;
     weaken $_[0];
     lazy {
@@ -731,7 +731,7 @@ sub stream_take {
 *FP::List::List::stream_take = *stream_take;
 
 sub stream_take_while {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $s) = @_;
     weaken $_[1];
     lazy {
@@ -752,7 +752,7 @@ sub stream_take_while {
 *FP::List::List::stream_take_while = flip \&stream_take_while;
 
 sub stream_slice {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($start, $end) = @_;
     weaken $_[0];
     weaken $_[1];
@@ -784,7 +784,7 @@ sub stream_slice {
 # maybe call it `cut_at` instead?
 
 sub stream_drop_while {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $s) = @_;
     weaken $_[1];
     lazy {
@@ -807,7 +807,7 @@ sub stream_ref;
 *FP::List::List::stream_ref = *stream_ref;
 
 sub exn (&) {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($thunk) = @_;
     eval { &$thunk(); '' } // do { $@ =~ /(.*?) at/; $1 }
 }
@@ -844,7 +844,7 @@ TEST { stream_ref cons(0, stream(1, 2, 3)), 2 } 2;
 
 # force everything deeply
 sub F {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
 
     #weaken $_[0]; since I usually use it interactively, and should
@@ -871,7 +871,7 @@ sub F {
 }
 
 sub stream_to_array {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     weaken $_[0];
     my $res = [];
@@ -904,7 +904,7 @@ TEST {
 bless [1, 9, 16], "FP::_::PureArray";
 
 sub stream_to_list {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     weaken $_[0];
     array_to_list stream_to_array $l
@@ -913,7 +913,7 @@ sub stream_to_list {
 *FP::List::List::stream_list = *stream_to_list;
 
 sub stream_sort {
-    @_ == 1 or @_ == 2 or fp_croak_nargs "1 or 2";
+    @_ == 1 or @_ == 2 or fp_croak_arity "1 or 2";
     my ($l, $maybe_cmp) = @_;
     stream_to_purearray($l)->sort ($maybe_cmp)
 }
@@ -943,14 +943,14 @@ sub stream_group;
 *stream_group = FP::List::make_group(1);
 
 sub FP::List::List::stream_group {
-    @_ >= 2 and @_ <= 3 or fp_croak_nargs "2-3";
+    @_ >= 2 and @_ <= 3 or fp_croak_arity "2-3";
     my ($self, $equal, $maybe_tail) = @_;
     weaken $_[0];
     stream_group($equal, $self, $maybe_tail)
 }
 
 sub stream_mixed_flatten {
-    @_ >= 1 and @_ <= 3 or fp_croak_nargs "1-3";
+    @_ >= 1 and @_ <= 3 or fp_croak_arity "1-3";
     my ($v, $maybe_tail, $maybe_delay) = @_;
 
     #XXX needed, no? weaken $_[0] if ref $_[0];
@@ -960,7 +960,7 @@ sub stream_mixed_flatten {
 *FP::List::List::stream_mixed_flatten = *stream_mixed_flatten;
 
 sub stream_any {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $l) = @_;
     weaken $_[1];
     $l = force $l;
@@ -980,7 +980,7 @@ sub stream_any {
 
 # (meant as a debugging tool: turn stream to string)
 sub stream_show {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($s) = @_;
     join("", map {"  '$_'\n"} @{ stream_to_array $s })
 }
@@ -991,10 +991,10 @@ sub stream_show {
 # the left). Then it's basically a fold_right.
 
 sub stream_state_fold_right {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $stateupfn, $s) = @_;
     sub {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my ($statedown) = @_;
         no warnings 'recursion';
         FORCE $s;
@@ -1082,7 +1082,7 @@ TEST {
 # introduction?)
 
 sub stream_mixed_fold_right {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $state, $v) = @_;
     weaken $_[2] if ref $_[2];
     @_ = ($fn, $state, stream_mixed_flatten $v);
@@ -1092,7 +1092,7 @@ sub stream_mixed_fold_right {
 *FP::List::List::stream_mixed_fold_right = rot3left \&stream_mixed_fold_right;
 
 sub stream_mixed_state_fold_right {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $statefn, $v) = @_;
     weaken $_[2] if ref $_[2];
     @_ = ($fn, $statefn, stream_mixed_flatten $v);
@@ -1105,7 +1105,7 @@ sub stream_mixed_state_fold_right {
 # 'cross product'
 
 sub stream_cartesian_product_2 {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($a, $orig_b) = @_;
     weaken $_[0];
     weaken $_[1];
@@ -1192,7 +1192,7 @@ list(list(1, 3), list(1, 4), list(2, 3), list(2, 4));
 sub make_chunks_of {
     my ($strictly, $lazy) = @_;
     sub {
-        @_ == 2 or fp_croak_nargs 2;
+        @_ == 2 or fp_croak_arity 2;
         my ($s, $chunklen) = @_;
         $chunklen >= 1 or croak "invalid chunklen: $chunklen";
         weaken $_[0] if $lazy;    # although tie down is only chunk sized
